cookiecutter-science-project_demo_repo
==============================
[![Build Status](https://github.com/jbusecke/cookiecutter-science-project_demo_repo/workflows/Tests/badge.svg)](https://github.com/jbusecke/cookiecutter-science-project_demo_repo/actions)
[![codecov](https://codecov.io/gh/jbusecke/cookiecutter-science-project_demo_repo/branch/master/graph/badge.svg)](https://codecov.io/gh/jbusecke/cookiecutter-science-project_demo_repo)
[![License:BSD-3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-lightgray.svg?style=flt-square)](https://opensource.org/licenses/BSD-3-Clause)

[![pypi](https://img.shields.io/pypi/v/cookiecutter-science-project_demo_repo.svg)](https://pypi.org/project/cookiecutter-science-project_demo_repo)
<!-- [![conda-forge](https://img.shields.io/conda/dn/conda-forge/cookiecutter-science-project_demo_repo?label=conda-forge)](https://anaconda.org/conda-forge/cookiecutter-science-project_demo_repo)
[![Documentation Status](https://readthedocs.org/projects/cookiecutter-science-project_demo_repo/badge/?version=latest)](https://cookiecutter-science-project_demo_repo.readthedocs.io/en/latest/?badge=latest) -->

Testing for cookiecutter template

--------

<p><small>Project based on the <a target="_blank" href="https://github.com/jbusecke/cookiecutter-science-project">cookiecutter science project template</a>.</small></p>
